@@ -12,6 +12,7 @@
 //
 //////////////////////////////////////////////////////////////////
 
+#include <ptlib.h>
 #include "singleton.h"
 
 #if PTRACING
@@ -20,11 +21,11 @@ static int singleton_cnt=0;
 
 listptr<SingletonBase> SingletonBase::_instance_list;
 
-SingletonBase::SingletonBase()
+SingletonBase::SingletonBase(const char *n) : m_name(n)
 {
 #if PTRACING
 	++singleton_cnt;
-	PTRACE(5,"Create instance: "<<singleton_cnt<<endl);
+	PTRACE(2,"Create instance: "<<m_name<<'('<<singleton_cnt<<')');
 #endif
 	_instance_list.push_back(this);
 }
@@ -33,7 +34,7 @@ SingletonBase::~SingletonBase()
 {
 #if PTRACING
 	--singleton_cnt;
-	PTRACE(5,"Delete instance: "<<singleton_cnt<<" objects left"<<endl);
+	PTRACE(2,"Delete instance: "<<m_name<<'('<<singleton_cnt<<" objects left)");
 #endif
 	if (!_instance_list.clear_list)
 		_instance_list.remove(this);
